==> antiright-2.99.4.tar.bz2: antiright/gtkshell/dialog_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_message_dialog(GtkMessageType type, char *text)
{
	GtkWidget *dialog;
	dialog=gtk_message_dialog_new(
		GTK_WINDOW(gsh_window),
		GTK_DIALOG_DESTROY_WITH_PARENT,
		type,
		GTK_BUTTONS_CLOSE,
		(gchar*)text);
	gtk_dialog_run(GTK_DIALOG (dialog));
	exit(0);
}
void
gsh_setup_message_dialog(int argc, char **argv,
	unsigned int *counter, GtkMessageType type)
{
	gsh_count(argc, counter);
	gsh_message_dialog(type, argv[(*counter)]);
}

void
gsh_font_dialog()
{
	GtkWidget *dialog;

	dialog=gtk_font_selection_dialog_new("Font Selector");
	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
	{
		gchar *font;
		font=gtk_font_selection_dialog_get_font_name(
			GTK_FONT_SELECTION_DIALOG(dialog));
		puts(font);
		g_free(font);
	}
	exit(0);
}


void
gsh_handle_dialog_arguments(int argc, char **argv,
	unsigned int *counter)
{
	assert(strlen(argv[(*counter)])>2);
	switch(argv[(*counter)][2])
	{
		case 'D': /* Folder Creation Selector */
			gsh_folder_create_dialog();
			break;
		case 'd': /* Folder Selector */
			gsh_folder_open_dialog();
			break;
		case 'e': /* Error Message */
			gsh_setup_message_dialog(argc,argv,
				counter, GTK_MESSAGE_ERROR);
			break;
		case 'F': /* Font Selection */
			gsh_font_dialog();
		case 'f': /* File Selection */
			gsh_file_open_dialog();
			break;
		case 'i': /* Information */
			gsh_setup_message_dialog(argc,argv,
				counter, GTK_MESSAGE_INFO);
			break;
		case 's': /* Filename Selection for Saving */
			gsh_file_save_dialog();
			break;
		case 'w': /* Warning */
			gsh_setup_message_dialog(argc,argv,
				counter,
				GTK_MESSAGE_WARNING);
			break;

	}
}

==> antiright-2.99.7.tar.bz2: antiright/gtkshell/dialog_options.c <==
/*
  AntiRight
  (c) 2002-2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_message_dialog(struct GSH *gsh, GtkMessageType type, char *text)
{
	GtkWidget *dialog;
	dialog=gtk_message_dialog_new(
		GTK_WINDOW(gsh->window),
		GTK_DIALOG_DESTROY_WITH_PARENT,
		type,
		GTK_BUTTONS_CLOSE,
		(gchar*)text);
	gtk_dialog_run(GTK_DIALOG (dialog));
	exit(0);
}
void
gsh_setup_message_dialog(struct GSH *gsh, int argc, char **argv,
	unsigned int *counter, GtkMessageType type)
{
	gsh_count(argc, counter);
	gsh_message_dialog(gsh, type, argv[(*counter)]);
}

void
gsh_font_dialog()
{
	GtkWidget *dialog;

	dialog=gtk_font_selection_dialog_new("Font Selector");
	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
	{
		gchar *font;
		font=gtk_font_selection_dialog_get_font_name(
			GTK_FONT_SELECTION_DIALOG(dialog));
		g_print("%s\n", font);
		g_free(font);
	}
	exit(0);
}


void
gsh_handle_dialog_arguments(struct GSH *gsh, int argc, char **argv,
	int *counter)
{
	assert(strlen(argv[(*counter)])>2);
	switch(argv[(*counter)][2])
	{
		case 'D': /* Folder Creation Selector */
			gsh_folder_create_dialog(gsh);
			break;
		case 'd': /* Folder Selector */
			gsh_folder_open_dialog(gsh);
			break;
		case 'e': /* Error Message */
			gsh_setup_message_dialog(gsh,argc,argv,
				counter, GTK_MESSAGE_ERROR);
			break;
		case 'F': /* Font Selection */
			gsh_font_dialog();
		case 'f': /* File Selection */
			gsh_file_open_dialog(gsh);
			break;
		case 'i': /* Information */
			gsh_setup_message_dialog(gsh,argc,argv,
				counter, GTK_MESSAGE_INFO);
			break;
		case 's': /* Filename Selection for Saving */
			gsh_file_save_dialog(gsh);
			break;
		case 'w': /* Warning */
			gsh_setup_message_dialog(gsh,argc,argv,
				counter,
				GTK_MESSAGE_WARNING);
			break;

	}
}
